@@ -1,49 +1,21 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                           )--------------------
-# Copyright (c) 2014-2021 Beartype authors.
+# Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
-**Beartype decorator PEP-compliant type-checking code generator magic.**
-
-This private submodule declares read-only global attributes internally
-referenced by the :mod:`beartype._decor._hint._pep._pephint` submodule,
-improving the maintainability and readability of the latter.
+**Beartype decorator PEP-compliant code generator magic** (i.e., global
+constants simplifying PEP-compliant code generation but *not* themselves code).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                           }....................
-from beartype._util.cache.utilcacheerror import EXCEPTION_CACHED_PLACEHOLDER
 from itertools import count
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
 
-# ....................{ CONSTANTS ~ exception             }....................
-EXCEPTION_PREFIX_FUNC_WRAPPER_LOCAL = (
-    f'{EXCEPTION_CACHED_PLACEHOLDER} wrapper parameter ')
-'''
-Human-readable substring describing a new wrapper parameter required by the
-current root type hint in exception messages.
-'''
-
-
-EXCEPTION_PREFIX_HINT_ROOT = EXCEPTION_CACHED_PLACEHOLDER
-'''
-Human-readable substring describing the current root type hint in exception
-messages.
-'''
-
-
-EXCEPTION_PREFIX_HINT_ROOT_GENERIC = (
-    f'{EXCEPTION_CACHED_PLACEHOLDER} type hint ')
-'''
-Human-readable substring describing the current root type hint generically
-(i.e., *without* respect to the specific PEP to which this hint conforms) in
-exception messages.
-'''
-
 # ....................{ CONSTANTS ~ hint : meta           }....................
 # Iterator yielding the next integer incrementation starting at 0, to be safely
 # deleted *AFTER* defining the following 0-based indices via this iterator.
@@ -86,8 +58,8 @@ For both space and time efficiency, this metadata is intentionally stored as
      Separate:
      2000000 loops, best of 5: 199 nsec per loop
 
-  So, not only does there exist no performance benefit to smaller fixed lists,
-  there exists demonstrable performance costs.
+So, not only does there exist no performance benefit to flattened fixed lists,
+there exists demonstrable performance costs.
 '''
 
 
