@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                           )--------------------
-# Copyright (c) 2014-2021 Beartype authors.
+# Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -23,8 +23,8 @@ Python 3.7.0.** If this is *not* the case, importing this submodule raises an
 # ....................{ IMPORTS                           }....................
 from __future__ import annotations
 from beartype import beartype
+from beartype.typing import List
 from beartype._cave._cavefast import IntType
-from beartype._util.hint.pep.utilpepattr import HINT_ATTR_LIST
 from beartype_test.a00_unit.data.data_type import decorator
 from collections.abc import Callable
 from typing import Union
@@ -149,7 +149,7 @@ def get_minecraft_end_txt_closure(player_name: str) -> Callable:
     # PEP-compliant type hints accessible only as local variables to the
     # following closure, exercising a significant edge case in PEP 563 support.
     StringLike = Union[str, int, bytes]
-    ListOfStrings = HINT_ATTR_LIST[str]
+    ListOfStrings = List[str]
 
     # Intentionally delimited by one layer of decoration to exercise edges.
     @decorator
@@ -189,7 +189,7 @@ def get_minecraft_end_txt_closure_factory(player_name: str) -> Callable:
     # following closure, exercising a significant edge case in PEP 563 support.
     IntLike = Union[float, int]
     ReturnType = Callable
-    InnerReturnType = HINT_ATTR_LIST[str]
+    InnerReturnType = List[str]
 
     # Intentionally delimited by two layers of decoration to exercise edges.
     @decorator
@@ -295,7 +295,7 @@ class MinecraftEndTxtUnscrambler(object):
 
 # ....................{ CALLABLES ~ limit                 }....................
 #FIXME: Hilariously, we can't even unit test whether the
-#beartype._decor._pep563._die_if_hint_repr_exceeds_child_limit() function
+#beartype._decor._pep.pep563._die_if_hint_repr_exceeds_child_limit() function
 #behaves as expected. Why not? Because some combination of the "typing" module
 #and/or PEP 563 were implemented so space-inefficiently than even attempting to
 #instantiate a PEP-compliant type hint that would violate the child limit
@@ -324,7 +324,7 @@ class MinecraftEndTxtUnscrambler(object):
 # _HINT_BIG = None
 # '''
 # PEP-compliant type hint guaranteed to raise an exception from the private
-# :func:`beartype._decor._pep563._die_if_hint_repr_exceeds_child_limit`
+# :func:`beartype._decor._pep.pep563._die_if_hint_repr_exceeds_child_limit`
 # function, which imposes strict limits on the number of child hints permitted to
 # be transitively nested in any top-level PEP-compliant type hint.
 # '''
